from temujin.layout.page import Page


class _BaseActionPlayer(object):
    """
    apply some actions (related to widgets) on device.
    something like click, swipe, etc.
    """


class _BaseStatusManager(object):
    """
    device status
    """


class _BaseExtractor(object):
    """
    this class was built for extracting
    device related things (xml, pic, etc.)
    to Page object.
    """

    # TODO different types of input
    def extract(self) -> Page:
        raise NotImplementedError


class _BaseDevice(object):
    """
    3 parts:
        - action player
        - status manager
        - extractor
    """

    ACTION_PLAYER_KLS = _BaseActionPlayer
    STATUS_MANAGER_KLS = _BaseStatusManager
    EXTRACTOR_KLS = _BaseExtractor



from temujin.device.base import (
    _BaseDevice,
    _BaseExtractor,
    _BaseActionPlayer,
    _BaseStatusManager,
)
from temujin.layout.page import Page


class AndroidActionPlayer(_BaseActionPlayer):
    pass


class AndroidStatusManager(_BaseStatusManager):
    pass


class AndroidExtractor(_BaseExtractor):
    def extract(self) -> Page:
        raise NotImplementedError


class AndroidDevice(_BaseDevice):
    ACTION_PLAYER_KLS = AndroidActionPlayer
    STATUS_MANAGER_KLS = AndroidStatusManager
    EXTRACTOR_KLS = AndroidExtractor



from setuptools import setup, find_packages
from temujin import (
    __AUTHOR__,
    __AUTHOR_EMAIL__,
    __URL__,
    __LICENSE__,
    __VERSION__,
    __PROJECT_NAME__,
    __DESCRIPTION__,
)

setup(
    name=__PROJECT_NAME__,
    version=__VERSION__,
    description=__DESCRIPTION__,
    author=__AUTHOR__,
    author_email=__AUTHOR_EMAIL__,
    url=__URL__,
    packages=find_packages(),
    include_package_data=True,
    license=__LICENSE__,
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    python_requires=">=3.6",
    install_requires=[],
)
